package com.cpxt.web.controller.biz;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.cpxt.common.annotation.Log;
import com.cpxt.common.core.controller.BaseController;
import com.cpxt.common.core.domain.AjaxResult;
import com.cpxt.common.enums.BusinessType;
import com.cpxt.biz.domain.BizCustomerUser;
import com.cpxt.biz.service.IBizCustomerUserService;
import com.cpxt.common.utils.poi.ExcelUtil;
import com.cpxt.common.core.page.TableDataInfo;

/**
 * 用户Controller
 * 
 * @author YIN
 * @date 2024-12-16
 */
@RestController
@RequestMapping("/biz/user")
public class BizCustomerUserController extends BaseController
{
    @Autowired
    private IBizCustomerUserService bizCustomerUserService;

    /**
     * 查询用户列表
     */
    @PreAuthorize("@ss.hasPermi('biz:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizCustomerUser bizCustomerUser)
    {
        startPage();
        List<BizCustomerUser> list = bizCustomerUserService.selectBizCustomerUserList(bizCustomerUser);
        return getDataTable(list);
    }

    /**
     * 导出用户列表
     */
    @PreAuthorize("@ss.hasPermi('biz:user:export')")
    @Log(title = "用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizCustomerUser bizCustomerUser)
    {
        List<BizCustomerUser> list = bizCustomerUserService.selectBizCustomerUserList(bizCustomerUser);
        ExcelUtil<BizCustomerUser> util = new ExcelUtil<BizCustomerUser>(BizCustomerUser.class);
        util.exportExcel(response, list, "用户数据");
    }

    /**
     * 获取用户详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:user:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bizCustomerUserService.selectBizCustomerUserById(id));
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.hasPermi('biz:user:add')")
    @Log(title = "用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizCustomerUser bizCustomerUser)
    {
        return toAjax(bizCustomerUserService.insertBizCustomerUser(bizCustomerUser));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.hasPermi('biz:user:edit')")
    @Log(title = "用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizCustomerUser bizCustomerUser)
    {
        return toAjax(bizCustomerUserService.updateBizCustomerUser(bizCustomerUser));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.hasPermi('biz:user:remove')")
    @Log(title = "用户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bizCustomerUserService.deleteBizCustomerUserByIds(ids));
    }
}
